@@ -19,7 +19,7 @@
  * is" without express or implied warranty.
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
- * @copyright  2003-2012 PgPool Global Development Group
+ * @copyright  2003-2013 PgPool Global Development Group
  * @version    SVN: $Id$
  */
 
@@ -305,7 +305,7 @@ function conStr($num, $mode = NULL)
                                          'health_check_password'));
         $user     = $params['health_check_user'];
         $password = (isset($params['health_check_user'])) ?
-                    $params['health_check_pasword'] : NULL;
+                    $params['health_check_password'] : NULL;
     }
 
     // backkend info
@@ -603,6 +603,7 @@ function paramExists($param)
             break;
 
         // params added in 3.0
+        case 'pool_passwd':
         case 'master_slave_sub_mode':
         case 'delay_threshold':
         case 'log_standby_delay':
